@@ -1,6 +1,6 @@
 from django.views.generic import ListView
 
-from settings import FAQ_SEARCH
+import settings
 
 from . import models
 from .forms import FAQSearchForm
@@ -12,14 +12,14 @@ class FAQIndex(ListView):
     """
 
     model = models.Category
-    template_name = "index.html"
+    template_name = "faqs/index.html"
 
     def get_queryset(self):
         """
         Override get method here to allow us to filter using tags
         """
         queryset = models.Category.objects.all()
-        if not FAQ_SEARCH:
+        if not settings.FAQ_SEARCH:
             return queryset
 
         form = FAQSearchForm(data=self.request.GET or None, queryset=queryset)
@@ -41,7 +41,7 @@ class FAQIndex(ListView):
             "faq_queryset": self.object_list,
             "form": FAQSearchForm(
                 queryset=self.object_list, initial=self.get_initial()
-            ) if FAQ_SEARCH else None,
+            ) if settings.FAQ_SEARCH else None,
         }
 
         return context
